/*
* 	Android Client API 
*/

/**
 * Requests permissions at runtime
 * @param name - permission name (string)
 */
function requestPermission(name) {
	Android.requestPermission(name);
}

/**
 * Requests permissions at runtime
 * @param name - permission name (string)
 */
function requestPermissions(list) {
	Android.requestPermissions(list);
}

/**
 * Check the permission status
 * @param permission name
 * @return 0 if granted, 1 denied and 2 never ask
 */
function getPermissionStatus(name) {
	return Android.getPermissionStatus(name);
}

/**
 * Check if main permissions are granted or if may not ask again,
 * false if at least one of them were only denied
 * @return true if granted or neverask again, false if denied
 */
function permissionsWereHandled() {
	return Android.permissionsWereHandled();
}

/**
 * Send stats about the web optin acceptance to the backend
 * @param column from database where to save stats
 * @param level null if always log or "uitest" if server controlled
 */
function sendStats(column, level) {
	Android.sendStats(column, level);
}

/**
 * Provides information about the device, system and app.
 * @return parameters to the URL
 */
function getDeviceInfo() {
	return Android.getDeviceInfo();
}

/**
 * Set time in milliseconds when a slide page is loaded
 */
function setTimePageHasBeenLoaded(time) {
	Android.setTimePageHasBeenLoaded(time);
}

/**
 * Set time in milliseconds when a slide page is loaded
 */
function setTimePageShouldBeLocked(time) {
	Android.setTimePageShouldBeLocked(time);
}

/**
 * Closes the optin and starts handling other permissions if necessary
 */
function closeWebOptin() {
	Android.closeWebOptin();
}

/**
 * Defines if the optin should be shown next time
 * @param value true if should not be shown, false otherwise
 */
function showOptinAgain(value) {
	Android.showOptinAgain(value);
}

/**
 * Pops up a dialog with customized text.
 * @param title - dialog title (string)
 * @param message - dialog message (string)
 * @param positiveBt - text to show on the positive button (string)
 * @param negativeBt - text to show on the positive button (string)
 */
function showDialog(title, message, negativeBt, positiveBt) {
	Android.showDialog(title, message, negativeBt, positiveBt);
}

/** 
 * Shows a toast message to the client
 * @param value - message
 */
function showToast(message) {
	Android.showToast(message);
}

/**
 * When user has accepted the terms but not necessarily finished handling permissions
 * @param accepted - true if accepted, false otherwise
 */
function acceptCalldorado(accepted) {
	Android.acceptCalldorado(accepted);
}

/**
 * List of conditions accepted e.g. "eula", "privacy"
 * @param conditions - array of strings, each a condition name
 * @param accepted - array of booleans, true if respective condition accepted
 */
function acceptConditions(conditions, accepted) {
	Android.acceptConditions(conditions, accepted);
}

/**
 * @return name of the host app
 */
function getAppName() {
	return Android.getAppName();
}

/**
 * @return true if conditions were accepted
 */
function calldoradoAccepted() {
	return Android.calldoradoAccepted();
}

/**
 * Open CallerId settings
 */
function goToSettings() {
	Android.goToSettings();
}

/**
 * Open email options
 */
function sendEmailTo(email) {
    Android.sendEmailTo(email);    
}

/**
 * Open url on native browser
 */
function openLink(url) {
	Android.openLink(url);
}

/**
 * Open url on dialog
 */
function openLinkOnDialog(url) {
	Android.openLink(url);
	/*
	if (getCdoVersion() >= 445) {
		Android.openLinkOnDialog(url);
	}
	else openLink(url);
	*/
}

/**
 * @return icon of the host app (string base64)
 */
function getAppIcon() {
	return Android.getAppIcon();
}

/**
 * @return version (int) of calldorado sdk
 */
function getCdoVersion() {
	return Android.getCdoVersion();
}

/**
 * @return true if user is new or false if has upgraded before
 */
function isNewUser() {
	return Android.isNewUser();
}

/**
 * @return get string translation
 */
function getTranslation(key) {
	return Android.getTranslation(key);
}

/**
 * @return true user is located in USA
 */
function isUserInUSA() {
	return Android.isUserInUSA();
}

/**
 * @return true if Cuebiq class is there
 */
function hasCuebiqSDKClass() {
	return Android.hasCuebiqSDKClass();
}

/**
 * @return true if bought user outside EEA
 */
function shouldSkipEULA() {
	return Android.shouldSkipEULA();
}

/**
 * @return true if Cuebiq should be enabled
 */
function cuebiqShouldBeEnabled() {
	return Android.cuebiqShouldBeEnabled();
}

/*
* 	Util 
*/

function getStatus(value) {
	if (value == 0) return "accept";
	if (value == 1) return "deny";
	if (value == 2) return "neverask";
}

function setLockTime(time) {
	setTimePageShouldBeLocked(time);
	setTimePageHasBeenLoaded(new Date().getTime());
}

function disable() {
	showOptinAgain(false);
	acceptCalldorado(false);
	acceptConditions(["eula", "privacy"], [false, false]);
	sendStats("optin_web_eula_denied", "");
	closeWebOptin();
}